module W.Styles exposing
    ( view
    , lightTheme, darkTheme, lightAndDarkTheme, customTheme
    , borderWidth, clickArea, clickAreaSmall
    )

{-|

@docs view
@docs lightTheme, darkTheme, lightAndDarkTheme, customTheme
@docs borderWidth, clickArea, clickAreaSmall

-}

import Attr
import Html as H
import W.Internal.Helpers as WH
import W.Theme



-- Attrs


{-| -}
type alias Attribute msg =
    Attr.Attr (Attributes msg)


type alias Attributes msg =
    { borderWidth : Int
    , clickArea : Float
    , clickAreaSmall : Float
    , theme : Maybe (H.Html msg)
    }


defaultAttrs : Attributes msg
defaultAttrs =
    { borderWidth = 2
    , clickArea = 1.75
    , clickAreaSmall = 1.25
    , theme = Nothing
    }



-- View


{-| Default border width in pixels.
This value is used for things like input, select boxes and other elements.
-}
borderWidth : Int -> Attribute msg
borderWidth v =
    Attr.attr (\attrs -> { attrs | borderWidth = v })


{-| Default size for clickable inputs such as checkboxes and radio buttons.
-}
clickArea : Float -> Attribute msg
clickArea v =
    Attr.attr (\attrs -> { attrs | clickArea = v })


{-| Default size for the small variation of clickable inputs such as checkboxes and radio buttons.
-}
clickAreaSmall : Float -> Attribute msg
clickAreaSmall v =
    Attr.attr (\attrs -> { attrs | clickAreaSmall = v })


{-| Use a basic light theme. This is the default behavior.
-}
lightTheme : Attribute msg
lightTheme =
    Attr.attr
        (\attrs ->
            { attrs
                | theme =
                    Just
                        (W.Theme.globalTheme
                            { theme = W.Theme.lightTheme
                            , darkMode = W.Theme.noDarkMode
                            }
                        )
            }
        )


{-| Use a basic dark theme.
-}
darkTheme : Attribute msg
darkTheme =
    Attr.attr
        (\attrs ->
            { attrs
                | theme =
                    Just
                        (W.Theme.globalTheme
                            { theme = W.Theme.darkTheme
                            , darkMode = W.Theme.noDarkMode
                            }
                        )
            }
        )


{-| Use a basic theme with light or dark modes set based on user preferences.
-}
lightAndDarkTheme : Attribute msg
lightAndDarkTheme =
    Attr.attr
        (\attrs ->
            { attrs
                | theme =
                    Just
                        (W.Theme.globalTheme
                            { theme = W.Theme.lightTheme
                            , darkMode = W.Theme.darkModeFromSystemPreferences W.Theme.darkTheme
                            }
                        )
            }
        )


{-| Use a custom theme. Please refer to georgesboris/elm-theme package for a complete documentation.
-}
customTheme : { theme : W.Theme.Theme, darkMode : W.Theme.DarkMode } -> Attribute msg
customTheme v =
    Attr.attr
        (\attrs ->
            { attrs
                | theme =
                    Just
                        (W.Theme.globalTheme
                            { theme = v.theme
                            , darkMode = v.darkMode
                            }
                        )
            }
        )


{-| -}
view : List (Attribute msg) -> H.Html msg
view =
    Attr.withAttrs defaultAttrs
        (\attrs ->
            H.div
                []
                [ case attrs.theme of
                    Just theme ->
                        theme

                    Nothing ->
                        W.Theme.globalTheme
                            { theme = W.Theme.lightTheme
                            , darkMode = W.Theme.noDarkMode
                            }
                , H.node "style"
                    []
                    [ H.text ("""
:root {
    --w-cfg-border: """ ++ WH.px attrs.borderWidth ++ """;
    --w-cfg-click: """ ++ WH.rem attrs.clickArea ++ """;
    --w-cfg-click-sm: """ ++ WH.rem attrs.clickAreaSmall ++ """;
}      
""")
                    , H.text """.w--shadow-colored.w--shadow-inner,.w--shadow-colored.w--shadow-sm{--tw-shadow-color:rgb(var(--w-shadow)/0.05);--tw-shadow:var(--tw-shadow-colored)}.w--shadow-colored.w--shadow,.w--shadow-colored.w--shadow-lg,.w--shadow-colored.w--shadow-md,.w--shadow-colored.w--shadow-xl{--tw-shadow-color:rgb(var(--w-shadow)/0.1);--tw-shadow:var(--tw-shadow-colored)}.w--shadow-colored.w--shadow-2xl{--tw-shadow-color:rgb(var(--w-shadow)/0.25);--tw-shadow:var(--tw-shadow-colored)}.w\\/tint{background-color:rgb(var(--w-tint));color:rgb(var(--w-text))}.w\\/tint:is(a,button):is(:hover){background-color:rgb(var(--w-tint-strong))}.w\\/tint:is(a,button):is(:active){background-color:rgb(var(--w-tint-subtle))}.w\\/solid{background-color:rgb(var(--w-solid));color:rgb(var(--w-solid-text))!important}.w\\/solid:is(a,button):is(:hover){background-color:rgb(var(--w-solid-strong))}.w\\/solid:is(a,button):is(:active){background-color:rgb(var(--w-solid-subtle))}.w\\/focus:is(:focus-visible),.w\\/solid:is(a,button):is(:focus-visible),.w\\/tint:is(a,button):is(:focus-visible){outline:2px solid #0000!important;outline-offset:2px!important;box-shadow:0 0 0 1px rgb(var(--w-bg)),0 0 0 4px rgb(var(--w-accent-subtle))!important}.w\\/base{--w-color:base;--w-bg:var(--w-base-bg);--w-bg-subtle:var(--w-base-bg-subtle);--w-tint:var(--w-base-tint);--w-tint-subtle:var(--w-base-tint-subtle);--w-tint-strong:var(--w-base-tint-strong);--w-accent:var(--w-base-accent);--w-accent-subtle:var(--w-base-accent-subtle);--w-accent-strong:var(--w-base-accent-strong);--w-solid:var(--w-base-solid);--w-solid-subtle:var(--w-base-solid-subtle);--w-solid-strong:var(--w-base-solid-strong);--w-solid-text:var(--w-base-solid-text);--w-text:var(--w-base-text);--w-text-subtle:var(--w-base-text-subtle);--w-shadow:var(--w-base-shadow);color:rgb(var(--w-text))}.w\\/primary{--w-color:primary;--w-bg:var(--w-primary-bg);--w-bg-subtle:var(--w-primary-bg-subtle);--w-tint:var(--w-primary-tint);--w-tint-subtle:var(--w-primary-tint-subtle);--w-tint-strong:var(--w-primary-tint-strong);--w-accent:var(--w-primary-accent);--w-accent-subtle:var(--w-primary-accent-subtle);--w-accent-strong:var(--w-primary-accent-strong);--w-solid:var(--w-primary-solid);--w-solid-subtle:var(--w-primary-solid-subtle);--w-solid-strong:var(--w-primary-solid-strong);--w-solid-text:var(--w-primary-solid-text);--w-text:var(--w-primary-text);--w-text-subtle:var(--w-primary-text-subtle);--w-shadow:var(--w-primary-shadow);color:rgb(var(--w-text))}.w\\/secondary{--w-color:secondary;--w-bg:var(--w-secondary-bg);--w-bg-subtle:var(--w-secondary-bg-subtle);--w-tint:var(--w-secondary-tint);--w-tint-subtle:var(--w-secondary-tint-subtle);--w-tint-strong:var(--w-secondary-tint-strong);--w-accent:var(--w-secondary-accent);--w-accent-subtle:var(--w-secondary-accent-subtle);--w-accent-strong:var(--w-secondary-accent-strong);--w-solid:var(--w-secondary-solid);--w-solid-subtle:var(--w-secondary-solid-subtle);--w-solid-strong:var(--w-secondary-solid-strong);--w-solid-text:var(--w-secondary-solid-text);--w-text:var(--w-secondary-text);--w-text-subtle:var(--w-secondary-text-subtle);--w-shadow:var(--w-secondary-shadow);color:rgb(var(--w-text))}.w\\/success{--w-color:success;--w-bg:var(--w-success-bg);--w-bg-subtle:var(--w-success-bg-subtle);--w-tint:var(--w-success-tint);--w-tint-subtle:var(--w-success-tint-subtle);--w-tint-strong:var(--w-success-tint-strong);--w-accent:var(--w-success-accent);--w-accent-subtle:var(--w-success-accent-subtle);--w-accent-strong:var(--w-success-accent-strong);--w-solid:var(--w-success-solid);--w-solid-subtle:var(--w-success-solid-subtle);--w-solid-strong:var(--w-success-solid-strong);--w-solid-text:var(--w-success-solid-text);--w-text:var(--w-success-text);--w-text-subtle:var(--w-success-text-subtle);--w-shadow:var(--w-success-shadow);color:rgb(var(--w-text))}.w\\/warning{--w-color:warning;--w-bg:var(--w-warning-bg);--w-bg-subtle:var(--w-warning-bg-subtle);--w-tint:var(--w-warning-tint);--w-tint-subtle:var(--w-warning-tint-subtle);--w-tint-strong:var(--w-warning-tint-strong);--w-accent:var(--w-warning-accent);--w-accent-subtle:var(--w-warning-accent-subtle);--w-accent-strong:var(--w-warning-accent-strong);--w-solid:var(--w-warning-solid);--w-solid-subtle:var(--w-warning-solid-subtle);--w-solid-strong:var(--w-warning-solid-strong);--w-solid-text:var(--w-warning-solid-text);--w-text:var(--w-warning-text);--w-text-subtle:var(--w-warning-text-subtle);--w-shadow:var(--w-warning-shadow);color:rgb(var(--w-text))}.w\\/danger{--w-color:danger;--w-bg:var(--w-danger-bg);--w-bg-subtle:var(--w-danger-bg-subtle);--w-tint:var(--w-danger-tint);--w-tint-subtle:var(--w-danger-tint-subtle);--w-tint-strong:var(--w-danger-tint-strong);--w-accent:var(--w-danger-accent);--w-accent-subtle:var(--w-danger-accent-subtle);--w-accent-strong:var(--w-danger-accent-strong);--w-solid:var(--w-danger-solid);--w-solid-subtle:var(--w-danger-solid-subtle);--w-solid-strong:var(--w-danger-solid-strong);--w-solid-text:var(--w-danger-solid-text);--w-text:var(--w-danger-text);--w-text-subtle:var(--w-danger-text-subtle);--w-shadow:var(--w-danger-shadow);color:rgb(var(--w-text))}*,::backdrop,:after,:before{--tw-border-spacing-x:0;--tw-border-spacing-y:0;--tw-translate-x:0;--tw-translate-y:0;--tw-rotate:0;--tw-skew-x:0;--tw-skew-y:0;--tw-scale-x:1;--tw-scale-y:1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness:proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-color:#3b82f680;--tw-ring-offset-shadow:0 0 #0000;--tw-ring-shadow:0 0 #0000;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: ;--tw-contain-size: ;--tw-contain-layout: ;--tw-contain-paint: ;--tw-contain-style: }input[type=checkbox].w--checkbox{margin:0;-webkit-appearance:none;-moz-appearance:none;appearance:none;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);display:inline-flex;align-items:center;justify-content:center}input
.w--box[type=checkbox].w--checkbox{gap:var(--w-gap)}@media (min-width:1024px){input .w--box[type=checkbox].w--checkbox{gap:var(--lg-w-gap,var(--w-gap))}}input[type=checkbox].w--checkbox{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}input[type=checkbox].w--checkbox:checked{background-color:rgb(var(--w-bg))}input[type=checkbox].w--checkbox:hover{opacity:.9}input[type=checkbox].w--checkbox:active{opacity:.75}input[type=checkbox].w--checkbox:disabled{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}input[type=checkbox].w--checkbox{cursor:pointer}input[type=checkbox].w--checkbox:disabled{cursor:not-allowed}input[type=checkbox].w--checkbox{width:var(--w-cfg-click);height:var(--w-cfg-click);border:var(--w-cfg-border) solid rgb(var(--w-accent));&:before{opacity:0;display:block;content:"";width:1.5rem;height:1.5rem;background-image:linear-gradient(-45deg,#0000 65%,var(--bg) 65.99%),linear-gradient(45deg,#0000 75%,var(--bg) 75.99%),linear-gradient(-45deg,var(--bg) 40%,#0000 40.99%),linear-gradient(45deg,var(--bg) 30%,var(--fg) 30.99%,var(--fg) 40%,#0000 40.99%),linear-gradient(-45deg,var(--fg) 50%,var(--bg) 50.99%);transition:opacity .2s}&:checked:before{opacity:1}&:checked:disabled:before{opacity:.5}}input[type=checkbox].w--checkbox.w--small{width:1.25rem;height:1.25rem;&:before{content:"";width:1rem;height:1rem}}input[type=checkbox].w--checkbox.w--colorful{border-color:var(--fg)}input[type=checkbox].w--toggle{margin:0;-webkit-appearance:none;-moz-appearance:none;appearance:none;border-radius:var(--w-radius-sm);box-sizing:initial;border-radius:9999px;padding:var(--w-spacing-xs);box-sizing:border-box;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);display:inline-flex;align-items:center;justify-content:flex-start}input
.w--box[type=checkbox].w--toggle{gap:var(--w-gap)}@media (min-width:1024px){input .w--box[type=checkbox].w--toggle{gap:var(--lg-w-gap,var(--w-gap))}}input[type=checkbox].w--toggle{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}input[type=checkbox].w--toggle:before{display:block;--tw-content:""}input[type=checkbox].w--toggle.w--shadow-colored:before{content:var(--tw-content);--tw-shadow-color:rgb(var(--w-shadow)/0.1);--tw-shadow:var(--tw-shadow-colored)}input[type=checkbox].w--toggle:before{border-radius:9999px;--tw-shadow:0 1px 3px 0 #0000001a,0 1px 2px -1px #0000001a;--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color),0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s;transition-timing-function:cubic-bezier(0,0,.2,1)}input[type=checkbox].w--toggle:hover{opacity:.9}input[type=checkbox].w--toggle:active{opacity:.75}input[type=checkbox].w--toggle{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}input[type=checkbox].w--toggle:checked{background-color:rgb(var(--w-bg))}input[type=checkbox].w--toggle:before{--tw-translate-x:0}input[type=checkbox].w--toggle:before,input[type=checkbox].w--toggle:checked:before{content:var(--tw-content);transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}input[type=checkbox].w--toggle:checked:before{--tw-translate-x:100%}input[type=checkbox].w--toggle:disabled{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}input[type=checkbox].w--toggle{width:3.5rem;height:auto;border:var(--w-cfg-border) solid rgb(var(--w-accent));&:before{content:"";width:1.375rem;height:1.375rem;background:var(--fg)}&.w--colorful{border-color:var(--fg)}&.w--small{width:2.75rem;&:before{width:1rem;height:1rem}}}.w--input-color{display:inline-flex;position:relative;input[type=color]{box-sizing:border-box;width:var(--w-cfg-click);height:var(--w-cfg-click);border:var(--w-cfg-border) solid rgb(var(--w-accent));border-radius:var(--w-radius-md);padding:4px}&:after{display:block;content:"";position:absolute;z-index:1;top:3px;left:3px;right:3px;bottom:3px;pointer-events:none;border:var(--w-cfg-border) solid rgb(var(--w-bg));border-radius:var(--w-radius-sm);background:currentColor}&.w--is-small{input[type=color]{width:var(--w-cfg-click-small);height:var(--w-cfg-click-small)}&:after{border-radius:var(--w-radius-xs)}}&.w--is-rounded{&:after,input[type=color]{border-radius:9999px}}}input[type=radio].w--radio{margin:0;-webkit-appearance:none;-moz-appearance:none;appearance:none;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow);background-color:rgb(var(--w-bg));display:inline-flex;align-items:center;justify-content:center}input
.w--box[type=radio].w--radio{gap:var(--w-gap)}@media (min-width:1024px){input .w--box[type=radio].w--radio{gap:var(--lg-w-gap,var(--w-gap))}}input[type=radio].w--radio,input[type=radio].w--radio:before{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}input[type=radio].w--radio:before{display:block;--tw-content:"";background-color:currentColor;--tw-scale-x:0;--tw-scale-y:0;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));content:var(--tw-content);transition-timing-function:cubic-bezier(0,0,.2,1)}input[type=radio].w--radio:hover{opacity:.9}input[type=radio].w--radio:active{opacity:.75}input[type=radio].w--radio:checked{--tw-border-opacity:1;border-color:rgb(var(--w-accent-strong)/var(--tw-border-opacity))}input[type=radio].w--radio:checked:before{content:var(--tw-content);--tw-scale-x:1;--tw-scale-y:1;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}input[type=radio].w--radio:disabled{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}input[type=radio].w--radio{width:1.75rem;height:1.75rem;border:var(--w-cfg-border) solid rgb(var(--w-accent)/1);&:before{width:1rem;height:1rem}}input[type=radio].w--radio.w--small{width:1.25rem;height:1.25rem;&:before{width:.625rem;height:.625rem}}.w--pointer-events-none{pointer-events:none}.w--pointer-events-auto{pointer-events:auto}.w--fixed{position:fixed}.w--absolute{position:absolute}.w--relative{position:relative}.w--sticky{position:sticky}.w--inset-0{inset:0}.w--inset-x-0{left:0;right:0}.w--inset-x-\\[12px\\]{left:12px;right:12px}.w--inset-x-md{left:var(--w-spacing-md);right:var(--w-spacing-md)}.w--inset-y-0{top:0;bottom:0}.-w--top-px{top:-1px}.w--bottom-full{bottom:100%}.w--left-0{left:0}.w--left-full{left:100%}.w--right-\\[0\\.75rem\\]{right:.75rem}.w--right-full{right:100%}.w--top-0{top:0}.w--top-1\\/2{top:50%}.w--top-\\[28px\\]{top:28px}.w--top-full{top:100%}.w--z-0{z-index:0}.w--z-10{z-index:10}.w--z-20{z-index:20}.w--z-\\[9999\\]{z-index:9999}.w--m-0{margin:0}.w--m-auto{margin:auto}.-w--mt-\\[0\\.125rem\\]{margin-top:-.125rem}.-w--mt-\\[3px\\]{margin-top:-3px}.w--box-border{box-sizing:border-box}.w--block{display:block}.w--inline-block{display:inline-block}.w--flex{display:flex}.w--inline-flex{display:inline-flex}.w--table{display:table}.w--grid{display:grid}.w--hidden{display:none}.w--aspect-square{aspect-ratio:1/1}.w--aspect-\\[21\\/9\\]{aspect-ratio:21/9}.w--h-0{height:0}.w--h-\\[0\\.25rem\\]{height:.25rem}.w--h-\\[20px\\]{height:20px}.w--h-\\[28px\\]{height:28px}.w--h-\\[3\\.5rem\\]{height:3.5rem}.w--h-\\[32px\\]{height:32px}.w--h-\\[6px\\]{height:6px}.w--min-h-\\[32px\\]{min-height:32px}.w--min-h-\\[48px\\]{min-height:48px}.w--min-h-\\[50px\\]{min-height:50px}.w--min-h-\\[60px\\]{min-height:60px}.w--min-h-screen{min-height:100vh}.w--w-0{width:0}.w--w-\\[2\\.5rem\\]{width:2.5rem}.w--w-\\[40\\%\\]{width:40%}.w--w-\\[60\\%\\]{width:60%}.w--w-full{width:100%}.w--w-max{width:-moz-max-content;width:max-content}.w--min-w-\\[48px\\]{min-width:48px}.w--min-w-full{min-width:100%}.w--max-w-full{max-width:100%}.w--shrink-0{flex-shrink:0}.w--grow{flex-grow:1}.w--table-fixed{table-layout:fixed}.-w--translate-y-1\\/2{--tw-translate-y:-50%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}@keyframes w--w--animation-fade-slide{0%{opacity:0;transform:translateY(10px) scale(.9)}to{opacity:1;transform:translateY(0) scale(1)}}.w--animate-fade-slide{animation:w--w--animation-fade-slide .4s ease-out}@keyframes w--pulse{50%{opacity:.5}}.w--animate-pulse{animation:w--pulse 2s cubic-bezier(.4,0,.6,1) infinite}.w--cursor-not-allowed{cursor:not-allowed}.w--cursor-pointer{cursor:pointer}.w--list-none{list-style-type:none}.w--appearance-none{-webkit-appearance:none;-moz-appearance:none;appearance:none}.w--grid-cols-2{grid-template-columns:repeat(2,minmax(0,1fr))}.w--flex-row{flex-direction:row}.w--flex-col{flex-direction:column}.w--flex-wrap{flex-wrap:wrap}.w--flex-nowrap{flex-wrap:nowrap}.w--content-start{align-content:flex-start}.w--items-start{align-items:flex-start}.w--items-end{align-items:flex-end}.w--items-center{align-items:center}.w--items-stretch{align-items:stretch}.w--justify-start{justify-content:flex-start}.w--justify-end{justify-content:flex-end}.w--justify-center{justify-content:center}.w--justify-between{justify-content:space-between}.w--justify-around{justify-content:space-around}.w--justify-evenly{justify-content:space-evenly}.w--justify-stretch{justify-content:stretch}.w--gap-lg{gap:var(--w-spacing-lg)}.w--gap-md{gap:var(--w-spacing-md)}.w--gap-sm{gap:var(--w-spacing-sm)}.w--gap-xs{gap:var(--w-spacing-xs)}.w--space-x-md>:not([hidden])~:not([hidden]){--tw-space-x-reverse:0;margin-right:calc(var(--w-spacing-md)*var(--tw-space-x-reverse));margin-left:calc(var(--w-spacing-md)*(1 - var(--tw-space-x-reverse)))}.w--space-y-2xl>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-top:calc(var(--w-spacing-2xl)*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(var(--w-spacing-2xl)*var(--tw-space-y-reverse))}.w--space-y-sm>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-top:calc(var(--w-spacing-sm)*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(var(--w-spacing-sm)*var(--tw-space-y-reverse))}.w--self-stretch{align-self:stretch}.w--overflow-auto{overflow:auto}.w--overflow-hidden{overflow:hidden}.w--overflow-visible{overflow:visible}.w--overflow-x-auto{overflow-x:auto}.w--overflow-y-auto{overflow-y:auto}.w--overflow-x-hidden{overflow-x:hidden}.w--whitespace-pre-wrap{white-space:pre-wrap}.w--break-words{overflow-wrap:break-word}.w--rounded{border-radius:var(--w-radius-sm)}.w--rounded-full{border-radius:9999px}.w--rounded-lg{border-radius:var(--w-radius-lg)}.w--rounded-md{border-radius:var(--w-radius-md)}.w--rounded-sm{border-radius:var(--w-radius-xs)}.w--border{border-width:1px}.w--border-0{border-width:0}.w--border-2{border-width:2px}.w--border-\\[1px\\]{border-width:1px}.w--border-\\[2px\\]{border-width:2px}.w--border-\\[3px\\]{border-width:3px}.w--border-b-2{border-bottom-width:2px}.w--border-l{border-left-width:1px}.w--border-l-2{border-left-width:2px}.w--border-r{border-right-width:1px}.w--border-t{border-top-width:1px}.w--border-t-2{border-top-width:2px}.w--border-t-8{border-top-width:8px}.w--border-solid{border-style:solid}.w--border-none{border-style:none}.w--border-accent{--tw-border-opacity:1;border-color:rgb(var(--w-accent)/var(--tw-border-opacity))}.w--border-current{border-color:currentColor}.w--border-tint{--tw-border-opacity:1;border-color:rgb(var(--w-tint)/var(--tw-border-opacity))}.w--border-tint-subtle{--tw-border-opacity:1;border-color:rgb(var(--w-tint-subtle)/var(--tw-border-opacity))}.w--border-transparent{border-color:#0000}.w--border-t-accent{--tw-border-opacity:1;border-top-color:rgb(var(--w-accent)/var(--tw-border-opacity))}.w--bg-bg{--tw-bg-opacity:1;background-color:rgb(var(--w-bg)/var(--tw-bg-opacity))}.w--bg-black\\/30{background-color:#0000004d}.w--bg-current{background-color:currentColor}.w--bg-tint{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}.w--bg-tint-subtle{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.w--bg-transparent{background-color:initial}.w--p-0{padding:0}.w--p-lg{padding:var(--w-spacing-lg)}.w--p-md{padding:var(--w-spacing-md)}.w--p-sm{padding:var(--w-spacing-sm)}.w--p-xl{padding:var(--w-spacing-xl)}.w--p-xs{padding:var(--w-spacing-xs)}.w--px-lg{padding-left:var(--w-spacing-lg);padding-right:var(--w-spacing-lg)}.w--px-md{padding-left:var(--w-spacing-md);padding-right:var(--w-spacing-md)}.w--px-sm{padding-left:var(--w-spacing-sm);padding-right:var(--w-spacing-sm)}.w--px-xl{padding-left:var(--w-spacing-xl);padding-right:var(--w-spacing-xl)}.w--py-sm{padding-top:var(--w-spacing-sm);padding-bottom:var(--w-spacing-sm)}.w--py-xl{padding-top:var(--w-spacing-xl);padding-bottom:var(--w-spacing-xl)}.w--py-xs{padding-top:var(--w-spacing-xs);padding-bottom:var(--w-spacing-xs)}.w--pb-lg{padding-bottom:var(--w-spacing-lg)}.w--pb-md{padding-bottom:var(--w-spacing-md)}.w--pb-sm{padding-bottom:var(--w-spacing-sm)}.w--pb-xl{padding-bottom:var(--w-spacing-xl)}.w--pb-xs{padding-bottom:var(--w-spacing-xs)}.w--pl-lg{padding-left:var(--w-spacing-lg)}.w--pl-md{padding-left:var(--w-spacing-md)}.w--pl-sm{padding-left:var(--w-spacing-sm)}.w--pl-xl{padding-left:var(--w-spacing-xl)}.w--pl-xs{padding-left:var(--w-spacing-xs)}.w--pr-lg{padding-right:var(--w-spacing-lg)}.w--pr-md{padding-right:var(--w-spacing-md)}.w--pr-sm{padding-right:var(--w-spacing-sm)}.w--pr-xl{padding-right:var(--w-spacing-xl)}.w--pr-xs{padding-right:var(--w-spacing-xs)}.w--pt-\\[10px\\]{padding-top:10px}.w--pt-lg{padding-top:var(--w-spacing-lg)}.w--pt-md{padding-top:var(--w-spacing-md)}.w--pt-sm{padding-top:var(--w-spacing-sm)}.w--pt-xl{padding-top:var(--w-spacing-xl)}.w--pt-xs{padding-top:var(--w-spacing-xs)}.w--text-left{text-align:left}.w--text-center{text-align:center}.w--text-right{text-align:right}.w--indent-0{text-indent:0}.w--align-sub{vertical-align:sub}.w--align-super{vertical-align:super}.w--font-code{font-family:var(--w-font-code)}.w--font-heading{font-family:var(--w-font-heading)}.w--font-text{font-family:var(--w-font-text)}.w--text-2xl{font-size:1.5rem;line-height:2rem}.w--text-3xl{font-size:1.875rem;line-height:2.25rem}.w--text-4xl{font-size:2.25rem;line-height:2.5rem}.w--text-base{font-size:1rem;line-height:1.5rem}.w--text-lg{font-size:1.125rem;line-height:1.75rem}.w--text-sm{font-size:.875rem;line-height:1.25rem}.w--text-xl{font-size:1.25rem;line-height:1.75rem}.w--text-xs{font-size:.75rem;line-height:1rem}.w--font-bold{font-weight:700}.w--font-light{font-weight:300}.w--font-medium{font-weight:500}.w--font-normal{font-weight:400}.w--font-semibold{font-weight:600}.w--uppercase{text-transform:uppercase}.w--lowercase{text-transform:lowercase}.w--italic{font-style:italic}.w--leading-none{line-height:1}.w--tracking-wide{letter-spacing:.025em}.w--tracking-wider{letter-spacing:.05em}.w--text-default{--tw-text-opacity:1;color:rgb(var(--w-text)/var(--tw-text-opacity))}.w--text-subtle{--tw-text-opacity:1;color:rgb(var(--w-text-subtle)/var(--tw-text-opacity))}.w--underline{text-decoration-line:underline}.w--line-through{text-decoration-line:line-through}.w--no-underline{text-decoration-line:none}.w--opacity-0{opacity:0}.w--opacity-50{opacity:.5}.w--opacity-\\[0\\.60\\]{opacity:.6}.w--shadow{--tw-shadow:0 1px 3px 0 #0000001a,0 1px 2px -1px #0000001a;--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color),0 1px 2px -1px var(--tw-shadow-color)}.w--shadow,.w--shadow-lg{box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.w--shadow-lg{--tw-shadow:0 10px 15px -3px #0000001a,0 4px 6px -4px #0000001a;--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color),0 4px 6px -4px var(--tw-shadow-color)}.w--shadow-md{--tw-shadow:0 4px 6px -1px #0000001a,0 2px 4px -2px #0000001a;--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color),0 2px 4px -2px var(--tw-shadow-color)}.w--shadow-md,.w--shadow-none{box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.w--shadow-none{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000}.w--shadow-xl{--tw-shadow:0 20px 25px -5px #0000001a,0 8px 10px -6px #0000001a;--tw-shadow-colored:0 20px 25px -5px var(--tw-shadow-color),0 8px 10px -6px var(--tw-shadow-color)}.w--shadow-2xl,.w--shadow-xl{box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.w--shadow-2xl{--tw-shadow:0 25px 50px -12px #00000040;--tw-shadow-colored:0 25px 50px -12px var(--tw-shadow-color)}.w--outline-0{outline-width:0}.w--ring-offset-0{--tw-ring-offset-width:0px}.w--transition{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.w--bg{background-color:rgb(var(--w-bg))}.w--cfg-border{border:var(--w-cfg-border) solid rgb(var(--w-accent))}.w--box{--w-gap:0;--w-radius:0;--w-width:auto;--w-height:auto;--w-border-color:var(--w-accent);--tw-shadow-color:var(--w-shadow);--tw-shadow:var(--tw-shadow-colored);width:var(--w-width);height:var(--w-height);border-radius:var(--w-radius);border-color:var(--w-border-color);box-sizing:border-box}.w--box.w--box-padding{padding:var(--w-padding)}.w--box.w--box-min-width{min-width:var(--w-min-width)}.w--box.w--box-max-width{max-width:var(--w-max-width)}.w--box.w--box-gap.w--block>*+*{margin-top:var(--w-gap)}.w--box.w--flex,.w--box.w--grid,.w--box.w--inline-flex{gap:var(--w-gap)}.w--box.w--grid{--w-columns:repeat(12,minmax(0,1fr));grid-template-columns:var(--w-columns)}.w--box.w--grid-span{grid-column:var(--w-col-span)}.w--box.w--grid-start{grid-column-start:var(--w-col-start)}.w--box.w--grid-end{grid-column-end:var(--w-col-end)}@media (min-width:1024px){.w--box{width:var(--lg-w-width,var(--w-width));height:var(--lg-w-height,var(--w-height));border-radius:var(--lg-w-border-radius,var(--w-radius));border-color:var(--lg-w-border-color,var(--w-border-color))}.w--box.w--flex,.w--box.w--grid,.w--box.w--inline-flex{gap:var(--lg-w-gap,var(--w-gap))}.w--box.w-box-padding{padding:var(--lg-w-padding,var(--w-padding))}.w--box.w--box-min-width{min-width:var(--lg-w-min-width,var(--w-min-width))}.w--box.w--box-max-width{max-width:var(--lg-w-max-width,var(--w-max-width))}.w--box.w--box-gap.w--block>*+*{margin-top:var(--lg-w-gap,var(--w-gap))}.w--box.w--grid{grid-template-columns:var(--w-columns)}.w--box.w--grid-span{grid-column:var(--lg-w-col-span,var(--w-col-span))}.w--box.w--grid-start{grid-column-start:var(--lg-w-col-start,var(--w-col-start))}.w--box.w--grid-end{grid-column-end:var(--lg-w-col-end,var(--w-col-end))}}.w--grid-wrapper{grid-template-columns:var(--w-columns,repeat(12,minmax(0,1fr)));gap:var(--w-gap,0)}.w--grid-column{grid-column:var(--w-span,auto)}@media (min-width:1024px){.w--grid-wrapper{grid-template-columns:var(--lg-w-columns,var(--w-columns,repeat(12,minmax(0,1fr))));gap:var(--lg-w-gap,var(--w-gap,0))}.w--grid-column{grid-column:var(--lg-w-span,var(--w-span,auto))}}.w--input{border:var(--w-cfg-border) solid rgb(var(--w-accent));&:focus,&:focus-within,&:hover{border-color:rgb(var(--w-accent-strong))}&:active{border-color:rgb(var(--w-accent-subtle))}&:disabled{cursor:not-allowed}&[readonly=""]:disabled{cursor:default;border-color:rgb(var(--w-accent))!important}input:focus{outline:none;box-shadow:none}}.w--input:focus-visible,.w--input:has(input:focus-visible){outline:2px solid #0000!important;outline-offset:2px!important;box-shadow:0 0 0 1px rgb(var(--w-bg)),0 0 0 4px rgb(var(--w-accent-subtle))!important}.w--input input:focus-visible,.w--input select:focus-visible,.w--input textarea:focus-visible{outline:none;border:0;box-shadow:none}.w--input select option{color:var(--theme-base-fg);background-color:var(--theme-base-bg)}.w--input input+.w--input-icon:before,.w--input select+.w--input-icon:before{background:rgb(var(--theme-base-aux-ch)/.07)}.w--input input:focus+.w--input-icon:before,.w--input select:focus+.w--input-icon:before{background:var(--theme-base-bg)}.w--input input:disabled+.w--input-icon:before,.w--input select:disabled+.w--input-icon:before{background:rgb(var(--theme-base-aux-ch)/.3)}.w--input input[aria-readonly]:disabled+.w--input-icon:before,.w--input select[aria-readonly]:disabled+.w--input-icon:before{background:rgb(var(--theme-base-aux-ch)/.07)}.w--input input[aria-readonly]:-moz-read-only:focus+.w--input-icon:before,.w--input select[aria-readonly]:-moz-read-only:focus+.w--input-icon:before{background:rgb(var(--theme-base-aux-ch)/.1)}.w--input input[aria-readonly]:read-only:focus+.w--input-icon:before,.w--input select[aria-readonly]:read-only:focus+.w--input-icon:before{background:rgb(var(--theme-base-aux-ch)/.1)}input[type=range].w--slider{-webkit-appearance:none;-moz-appearance:none;appearance:none;position:relative;z-index:0;left:0;right:0;width:100%;margin:0;height:auto;opacity:1;outline:initial;background:#0000}input[type=range].w--slider:disabled{pointer-events:none}input[type=range].w--slider::-webkit-slider-runnable-track{background:initial;cursor:auto}input[type=range].w--slider::-moz-range-track{background:initial;cursor:auto}input[type=range].w--slider::-ms-track{background:initial;cursor:auto}input[type=range].w--slider::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;height:24px;width:24px;border-radius:50%;background:currentColor;border:var(--w-cfg-border) solid #fff;box-shadow:0 0 4px #0000001a;-webkit-transition:.12s ease-in;transition:.12s ease-in}input[type=range].w--slider:hover::-webkit-slider-thumb{box-shadow:0 0 4px #0000001a,0 0 4px currentColor}input[type=range].w--slider:active::-webkit-slider-thumb{-webkit-transition:none;transition:none;box-shadow:0 0 4px #0000001a,0 0 2px currentColor}input[type=range].w--slider:focus-visible::-webkit-slider-thumb{box-shadow:0 0 4px #0000001a,0 0 4px currentColor}input[type=range].w--slider::-moz-range-thumb{-moz-appearance:none;appearance:none;height:24px;width:24px;border-radius:50%;background:currentColor;border:var(--w-cfg-border) solid #fff;box-shadow:0 0 4px #0000001a;-moz-transition:.12s ease-in;transition:.12s ease-in}input[type=range].w--slider:hover::-moz-range-thumb{box-shadow:0 0 4px #0000001a,0 0 4px currentColor}input[type=range].w--slider:active::-moz-range-thumb{-moz-transition:none;transition:none;box-shadow:0 0 4px #0000001a,0 0 2px currentColor}input[type=range].w--slider:focus-visible::-moz-range-thumb{box-shadow:0 0 4px #0000001a,0 0 4px currentColor}.w--loading-dots{display:inline-block;position:relative;width:var(--size);height:var(--size)}.w--loading-dots div{position:absolute;top:calc(var(--size)*.4);width:calc(var(--size)*.2);height:calc(var(--size)*.2);border-radius:calc(var(--size)*.2);background:var(--color);animation-timing-function:cubic-bezier(0,1,1,0)}.w--loading-dots>div:first-child{left:0;animation:w--loading-dots-1 .6s infinite}.w--loading-dots>div:nth-child(2){left:0;animation:w--loading-dots-2 .6s infinite}.w--loading-dots>div:nth-child(3){left:calc(var(--size)*.4);animation:w--loading-dots-2 .6s infinite}.w--loading-dots>div:nth-child(4){left:calc(var(--size)*.8);animation:w--loading-dots-3 .6s infinite}@keyframes w--loading-dots-1{0%{transform:scale(0)}to{transform:scale(1)}}@keyframes w--loading-dots-2{0%{transform:translate(0)}to{transform:translate(calc(var(--size)*.4))}}@keyframes w--loading-dots-3{0%{transform:scale(1)}to{transform:scale(0)}}.w--loading-ripples{display:inline-block;position:relative;width:var(--size);height:var(--size)}.w--loading-ripples>div{position:absolute;border:calc(var(--size)*.06) solid var(--color);opacity:1;border-radius:50%;animation:w--loading-ripples 1.2s cubic-bezier(0,.2,.8,1) infinite}.w--loading-ripples>div:nth-child(2){animation-delay:-.6s}@keyframes w--loading-ripples{0%{top:calc(var(--size)*.5);left:calc(var(--size)*.5);width:0;height:0;opacity:1}to{top:0;left:0;width:var(--size);height:var(--size);opacity:0}}.w--menu-section:not(:first-child){padding-top:var(--w-menu-section-gap,var(--w-spacing-xl))}.w--modal-toggle:checked+.w--modal,.w--modal.w--modal--is-open{display:block;opacity:1}.w--modal-toggle:checked+.w--modal>.w--modal-content,.w--modal.w--modal--is-open>.w--modal-content{animation:w--animation-fade-slide-scale .2s ease-out forwards}.w--popover-content{display:none}.w--popover-trigger:focus-within+.w--popover-content,.w--popover.w--is-open>.w--popover-content{display:block;animation:w--animation-fade .2s forwards}.w--popover.w--is-closed .w--popover-trigger:focus-within+.w--popover-content{display:none}.w--popover.w--persistent:focus-within>.w--popover-content{display:block}.w--popover.w--show-on-hover .w--popover-trigger:hover+.w--popover-content{display:block;animation:w--animation-fade .2s forwards}.w--popover.w--show-on-hover>.w--popover-content:hover{display:block}.w--popover-content:active{display:block!important}.w--tooltip:after{content:"";display:block;position:absolute;border-style:solid}.w--tooltip.w--tooltip-top:after{top:100%;left:50%;margin-left:-2px;border-width:4px 4px 0;border-color:rgb(var(--w-solid)/1) #0000 #0000 #0000}.w--tooltip.w--tooltip-bottom:after{bottom:100%;left:50%;margin-left:-2px;border-width:0 4px 4px;border-color:#0000 #0000 rgb(var(--w-solid)/1) #0000}.w--tooltip.w--tooltip-left:after{top:50%;left:100%;margin-top:-2px;border-width:4px 0 4px 4px;border-color:#0000 #0000 #0000 rgb(var(--w-solid)/1)}.w--tooltip.w--tooltip-right:after{top:50%;right:100%;margin-top:-2px;border-width:4px 4px 4px 0;border-color:#0000 rgb(var(--w-solid)/1) #0000 #0000}.active\\:w--shadow-sm:active.w--shadow-colored{--tw-shadow-color:rgb(var(--w-shadow)/0.05);--tw-shadow:var(--tw-shadow-colored)}.before\\:w--absolute:before{content:var(--tw-content);position:absolute}.before\\:w--inset-0:before{content:var(--tw-content);inset:0}.before\\:w--block:before{content:var(--tw-content);display:block}.before\\:w--h-\\[1px\\]:before{content:var(--tw-content);height:1px}.before\\:w--h-\\[2px\\]:before{content:var(--tw-content);height:2px}.before\\:w--w-\\[1px\\]:before{content:var(--tw-content);width:1px}.before\\:w--w-\\[2px\\]:before{content:var(--tw-content);width:2px}.before\\:w--grow:before{content:var(--tw-content);flex-grow:1}.before\\:w--rounded:before{content:var(--tw-content);border-radius:var(--w-radius-sm)}.before\\:w--rounded-full:before{content:var(--tw-content);border-radius:9999px}.before\\:w--bg-current:before{content:var(--tw-content);background-color:currentColor}.before\\:w--opacity-10:before{content:var(--tw-content);opacity:.1}.before\\:w--content-\\[\\'\\'\\]:before{--tw-content:"";content:var(--tw-content)}.after\\:w--block:after{content:var(--tw-content);display:block}.after\\:w--h-\\[1px\\]:after{content:var(--tw-content);height:1px}.after\\:w--h-\\[2px\\]:after{content:var(--tw-content);height:2px}.after\\:w--w-\\[1px\\]:after{content:var(--tw-content);width:1px}.after\\:w--w-\\[2px\\]:after{content:var(--tw-content);width:2px}.after\\:w--grow:after{content:var(--tw-content);flex-grow:1}.after\\:w--bg-current:after{content:var(--tw-content);background-color:currentColor}.after\\:w--content-\\[\\'\\'\\]:after{--tw-content:"";content:var(--tw-content)}.focus-within\\:w--bg-tint-subtle:focus-within{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.focus-within\\:w--text-default:focus-within{--tw-text-opacity:1;color:rgb(var(--w-text)/var(--tw-text-opacity))}.hover\\:w--border-accent-strong:hover{--tw-border-opacity:1;border-color:rgb(var(--w-accent-strong)/var(--tw-border-opacity))}.hover\\:w--bg-tint:hover{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}.hover\\:w--bg-tint-strong:hover{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-strong)/var(--tw-bg-opacity))}.hover\\:w--bg-tint-subtle:hover{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.hover\\:before\\:w--opacity-\\[0\\.05\\]:hover:before{content:var(--tw-content);opacity:.05}.focus\\:w--z-10:focus{z-index:10}.focus\\:w--shadow-none:focus{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.focus\\:w--outline-none:focus{outline:2px solid #0000;outline-offset:2px}.focus-visible\\:w--bg-tint-subtle:focus-visible{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.focus-visible\\:w--outline-0:focus-visible{outline-width:0}.focus-visible\\:w--ring:focus-visible{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)}.active\\:w--border-accent-subtle:active{--tw-border-opacity:1;border-color:rgb(var(--w-accent-subtle)/var(--tw-border-opacity))}.active\\:w--bg-tint-subtle:active{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.active\\:w--shadow-sm:active{--tw-shadow:0 1px 2px 0 #0000000d;--tw-shadow-colored:0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)}.active\\:w--bg-subtle:active{background-color:rgb(var(--w-bg-subtle))}.active\\:before\\:w--opacity-10:active:before{content:var(--tw-content);opacity:.1}.active\\:before\\:w--opacity-\\[0\\.03\\]:active:before{content:var(--tw-content);opacity:.03}.disabled\\:w--bg-tint:disabled{--tw-bg-opacity:1;background-color:rgb(var(--w-tint)/var(--tw-bg-opacity))}.w--group:focus-within .group-focus-within\\:w--relative{position:relative}.w--group:focus-within .group-focus-within\\:w--rounded{border-radius:var(--w-radius-sm)}.w--group\\/w:focus-within .group-focus-within\\/w\\:w--border-accent-strong{--tw-border-opacity:1;border-color:rgb(var(--w-accent-strong)/var(--tw-border-opacity))}.w--group:focus-within .group-focus-within\\:w--bg-tint-subtle{--tw-bg-opacity:1;background-color:rgb(var(--w-tint-subtle)/var(--tw-bg-opacity))}.w--group:focus-within .group-focus-within\\:w--px-sm{padding-left:var(--w-spacing-sm);padding-right:var(--w-spacing-sm)}.w--group:focus-within .group-focus-within\\:w--text-sm{font-size:.875rem;line-height:1.25rem}.w--group:focus-within .group-focus-within\\:w--leading-relaxed{line-height:1.625}.w--group:focus-within .group-focus-within\\:w--text-subtle{--tw-text-opacity:1;color:rgb(var(--w-text-subtle)/var(--tw-text-opacity))}.w--group:hover .group-hover\\:w--translate-x-0{--tw-translate-x:0}.w--group:hover .group-hover\\:w--translate-x-0,.w--group:hover .group-hover\\:w--translate-y-0{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.w--group:hover .group-hover\\:w--translate-y-0{--tw-translate-y:0}.w--group\\/btn:hover .group-hover\\/btn\\:w--text-default{--tw-text-opacity:1;color:rgb(var(--w-text)/var(--tw-text-opacity))}.w--group:hover .group-hover\\:w--opacity-100{opacity:1}.w--group:hover .group-hover\\:w--delay-100{transition-delay:.1s}.w--group:hover .group-hover\\:w--delay-1000{transition-delay:1s}.w--group:hover .group-hover\\:w--delay-500{transition-delay:.5s}.w--group\\/btn:active .group-active\\/btn\\:w--text-subtle{--tw-text-opacity:1;color:rgb(var(--w-text-subtle)/var(--tw-text-opacity))}@media (min-width:1024px){.lg\\:w--fixed{position:fixed}.lg\\:w--absolute{position:absolute}.lg\\:w--relative{position:relative}.lg\\:w--sticky{position:sticky}.lg\\:w--block{display:block}.lg\\:w--flex{display:flex}.lg\\:w--inline-flex{display:inline-flex}.lg\\:w--table-cell{display:table-cell}.lg\\:w--aspect-square{aspect-ratio:1/1}.lg\\:w--min-h-screen{min-height:100vh}.lg\\:w--flex-row{flex-direction:row}.lg\\:w--flex-col{flex-direction:column}.lg\\:w--items-start{align-items:flex-start}.lg\\:w--items-end{align-items:flex-end}.lg\\:w--items-center{align-items:center}.lg\\:w--items-stretch{align-items:stretch}.lg\\:w--justify-start{justify-content:flex-start}.lg\\:w--justify-end{justify-content:flex-end}.lg\\:w--justify-center{justify-content:center}.lg\\:w--justify-between{justify-content:space-between}.lg\\:w--justify-around{justify-content:space-around}.lg\\:w--justify-evenly{justify-content:space-evenly}.lg\\:w--justify-stretch{justify-content:stretch}.lg\\:w--p-lg{padding:var(--w-spacing-lg)}.lg\\:w--p-md{padding:var(--w-spacing-md)}.lg\\:w--p-sm{padding:var(--w-spacing-sm)}.lg\\:w--p-xl{padding:var(--w-spacing-xl)}.lg\\:w--p-xs{padding:var(--w-spacing-xs)}.lg\\:w--pb-lg{padding-bottom:var(--w-spacing-lg)}.lg\\:w--pb-md{padding-bottom:var(--w-spacing-md)}.lg\\:w--pb-sm{padding-bottom:var(--w-spacing-sm)}.lg\\:w--pb-xl{padding-bottom:var(--w-spacing-xl)}.lg\\:w--pb-xs{padding-bottom:var(--w-spacing-xs)}.lg\\:w--pl-lg{padding-left:var(--w-spacing-lg)}.lg\\:w--pl-md{padding-left:var(--w-spacing-md)}.lg\\:w--pl-sm{padding-left:var(--w-spacing-sm)}.lg\\:w--pl-xl{padding-left:var(--w-spacing-xl)}.lg\\:w--pl-xs{padding-left:var(--w-spacing-xs)}.lg\\:w--pr-lg{padding-right:var(--w-spacing-lg)}.lg\\:w--pr-md{padding-right:var(--w-spacing-md)}.lg\\:w--pr-sm{padding-right:var(--w-spacing-sm)}.lg\\:w--pr-xl{padding-right:var(--w-spacing-xl)}.lg\\:w--pr-xs{padding-right:var(--w-spacing-xs)}.lg\\:w--pt-lg{padding-top:var(--w-spacing-lg)}.lg\\:w--pt-md{padding-top:var(--w-spacing-md)}.lg\\:w--pt-sm{padding-top:var(--w-spacing-sm)}.lg\\:w--pt-xl{padding-top:var(--w-spacing-xl)}.lg\\:w--pt-xs{padding-top:var(--w-spacing-xs)}}"""
                    ]
                ]
        )
